@@ -6,6 +6,7 @@ import sys
 import importlib
 import pkgutil
 import glob
+import six
 
 import deploy_config_generator.output as output_ns
 from deploy_config_generator.site_config import SiteConfig
@@ -42,6 +43,10 @@ def load_vars(varset, deploy_dir, env='BAD_VALUE_NO_MATCH'):
     tmp_vars = dict(env=env)
 
     # Load vars from site config
+    for key, value in list(SITE_CONFIG.default_vars.items()):
+        if not isinstance(value, six.string_types):
+            SITE_CONFIG.default_vars[key] = str(value)
+            DISPLAY.warn("implicitly converted non-string value for var '%s' from site config to string" % key)
     varset.update(SITE_CONFIG.default_vars)
 
     # Load env vars
@@ -182,7 +187,7 @@ def main():
         DISPLAY.vv('%s: %s' % (arg, getattr(args, arg)))
     DISPLAY.vv()
 
-    SITE_CONFIG = SiteConfig()
+    SITE_CONFIG = SiteConfig(env=args.env)
     if args.config is None:
         # Possible config locations
         config_paths = [
@@ -197,6 +202,7 @@ def main():
             SITE_CONFIG.load(args.config)
         except ConfigError as e:
             DISPLAY.display('Failed to load site config: %s' % str(e))
+            show_traceback(DISPLAY.get_verbosity())
             sys.exit(1)
 
     DISPLAY.vvvv('Site config:')
